@@ -4,7 +4,6 @@ from stripe.api_resources.abstract.api_resource import APIResource
 
 
 class DeletableAPIResource(APIResource):
-
     def delete(self, **params):
-        self.refresh_from(self.request('delete', self.instance_url(), params))
+        self.refresh_from(self.request("delete", self.instance_url(), params))
         return self
