@@ -6,12 +6,13 @@ from stripe.api_resources.abstract import UpdateableAPIResource
 from stripe.api_resources.abstract import ListableAPIResource
 
 
-class Payout(CreateableAPIResource, UpdateableAPIResource,
-             ListableAPIResource):
-    OBJECT_NAME = 'payout'
+class Payout(
+    CreateableAPIResource, UpdateableAPIResource, ListableAPIResource
+):
+    OBJECT_NAME = "payout"
 
     def cancel(self, idempotency_key=None, **params):
-        url = self.instance_url() + '/cancel'
+        url = self.instance_url() + "/cancel"
         headers = util.populate_headers(idempotency_key)
-        self.refresh_from(self.request('post', url, params, headers))
+        self.refresh_from(self.request("post", url, params, headers))
         return self
