@@ -6,6 +6,10 @@ from stripe.api_resources.abstract import UpdateableAPIResource
 from stripe.api_resources.abstract import ListableAPIResource
 
 
-class Product(CreateableAPIResource, UpdateableAPIResource,
-              ListableAPIResource, DeletableAPIResource):
-    OBJECT_NAME = 'product'
+class Product(
+    CreateableAPIResource,
+    UpdateableAPIResource,
+    ListableAPIResource,
+    DeletableAPIResource,
+):
+    OBJECT_NAME = "product"
